@@ -1,9 +1,9 @@
 package WordList::Test::Dynamic::OneTwo_FirstNextReset;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-03-05'; # DATE
+our $DATE = '2021-06-23'; # DATE
 our $DIST = 'WordList'; # DIST
-our $VERSION = '0.7.9'; # VERSION
+our $VERSION = '0.7.10'; # VERSION
 
 use strict;
 
@@ -36,7 +36,7 @@ sub next_word {
     else { return undef }
 }
 
-our %STATS = ("avg_word_len",3,"num_words_contain_nonword_chars",0,"num_words_contain_whitespace",0,"longest_word_len",3,"num_words_contain_unicode",0,"num_words_contains_whitespace",0,"num_words_contains_unicode",0,"shortest_word_len",3,"num_words",2,"num_words_contains_nonword_chars",0); # STATS
+our %STATS = ("avg_word_len",3,"num_words_contain_unicode",0,"num_words_contains_whitespace",0,"num_words_contain_whitespace",0,"num_words_contains_nonword_chars",0,"num_words",2,"shortest_word_len",3,"num_words_contains_unicode",0,"num_words_contain_nonword_chars",0,"longest_word_len",3); # STATS
 
 1;
 # ABSTRACT: Wordlist that returns one, two (via implementing first_word(), next_word(), and reset_iterator())
@@ -53,7 +53,7 @@ WordList::Test::Dynamic::OneTwo_FirstNextReset - Wordlist that returns one, two
 
 =head1 VERSION
 
-This document describes version 0.7.9 of WordList::Test::Dynamic::OneTwo_FirstNextReset (from Perl distribution WordList), released on 2021-03-05.
+This document describes version 0.7.10 of WordList::Test::Dynamic::OneTwo_FirstNextReset (from Perl distribution WordList), released on 2021-06-23.
 
 =head1 SYNOPSIS
 
@@ -62,11 +62,12 @@ This document describes version 0.7.9 of WordList::Test::Dynamic::OneTwo_FirstNe
  my $wl = WordList::Test::Dynamic::OneTwo_FirstNextReset->new;
 
  # Pick a (or several) random word(s) from the list
- my $word = $wl->pick;
- my @words = $wl->pick(3);
+ my ($word) = $wl->pick;
+ my ($word) = $wl->pick(1);  # ditto
+ my @words  = $wl->pick(3);  # no duplicates
 
  # Check if a word exists in the list
- if ($wl->word_exists('foo')) { ... }
+ if ($wl->word_exists('foo')) { ... }  # case-sensitive
 
  # Call a callback for each word
  $wl->each_word(sub { my $word = shift; ... });
@@ -75,7 +76,7 @@ This document describes version 0.7.9 of WordList::Test::Dynamic::OneTwo_FirstNe
  my $first_word = $wl->first_word;
  while (defined(my $word = $wl->next_word)) { ... }
 
- # Get all the words
+ # Get all the words (beware, some wordlists are *huge*)
  my @all_words = $wl->all_words;
 
 =head1 DESCRIPTION
@@ -90,7 +91,7 @@ Source repository is at L<https://github.com/perlancar/perl-WordList>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-WordList/issues>
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=WordList>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
