@@ -1,9 +1,9 @@
 package WordListRole::Test;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-03-05'; # DATE
+our $DATE = '2021-06-23'; # DATE
 our $DIST = 'WordList'; # DIST
-our $VERSION = '0.7.9'; # VERSION
+our $VERSION = '0.7.10'; # VERSION
 
 use Role::Tiny;
 
@@ -24,7 +24,7 @@ WordListRole::Test - A test role
 
 =head1 VERSION
 
-This document describes version 0.7.9 of WordListRole::Test (from Perl distribution WordList), released on 2021-03-05.
+This document describes version 0.7.10 of WordListRole::Test (from Perl distribution WordList), released on 2021-06-23.
 
 =head1 PROVIDED METHODS
 
@@ -40,7 +40,7 @@ Source repository is at L<https://github.com/perlancar/perl-WordList>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-WordList/issues>
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=WordList>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
